"""
Django settings for ROOT project.

Generated by 'django-admin startproject' using Django 1.8.3.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
MEDIA_URL = '/media/'

DDF_VALIDATE_ARGS = True
DDF_IGNORE_FIELDS = ['*_ptr']  # Ignore django-polymorphic pointer fields


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '+3#4(%u5c)2&e-4qqy#s%zo5u7r2)b&24u98d1f3n!mju+$+&x'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = (
    'polymorphic',
    'django_admin_bootstrapped',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_extensions',
    'django_cleanup',
    'django.contrib.humanize',
    'bootstrap4',
    'other',
    'members',
    'api',
    'import_app',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
)

ROOT_URLCONF = 'ROOT.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'ROOT.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}


# Internationalization
# https://docs.djangoproject.com/en/1.8/topics/i18n/
LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = False

# Country as 2 character code according to ISO 3661 Alpha 2.
# Used to determine national vs. international letters.
COUNTRY = 'DE'

# Number of returned snail mails until a person's address
# is considered unreachable.
ADDRESS_RETURNS = 2

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/static-files/
STATIC_URL = '/static/'

# Membership fee in cent
FEE = 7200
FEE_REDUCED = 3600
FEE_ENTRY = 0

# Number of months until a delayed_payment mail will be created
FEE_NOTIFICATION_TIME = 2

# Number of months without any reaction to overdue fees (counted from last-update date) until primary email address
# will be removed
EMAIL_REMOVE_TIME = 6

# Email configuration
EMAIL_USE_TLS = False
EMAIL_HOST = '127.0.0.1'
EMAIL_PORT = 1025
EMAIL_HOST_USER = 'user@test-mail.com'

# GPG fingerprint
GPG_HOST_USER = '127850E80BFE267BA70B637370E8B2020B04220B'

# Uncomment and set to your password to use SMTP AUTH
#EMAIL_HOST_PASSWORD = 'password'

# Email to which all monthly statistics and similar reports are sent (and GPG key)
EMAIL_MANAGING_DIRECTOR = 'vorstand@test-mail.com'
GPG_MANAGING_DIRECTOR = '4B6B9174638813A83E8368ED059ACC5D37B1245E'

# Name substituted for empty Erfas
EMPTY_ERFA_NAME = 'Alien'

# Folder with GPG keys
GPG_HOME = 'gpg_home_folder'

# Set this to the not yet released Datenschleuder issue number
# and only increment this value after successfully sending out
# the current issue, because otherwise some subscribers might
# get deleted before they received their last issue.
NEXT_DATENSCHLEUDER_ISSUE = 98

try:
    from .settings_production import *  # noqa
except ImportError:
    print("Could not import production settings.")
